@@ -12,13 +12,12 @@ struct _AdwDemoPageToasts
 
 enum {
   SIGNAL_ADD_TOAST,
-  SIGNAL_DISMISS_ALL,
   SIGNAL_LAST_SIGNAL,
 };
 
 static guint signals[SIGNAL_LAST_SIGNAL];
 
-G_DEFINE_FINAL_TYPE (AdwDemoPageToasts, adw_demo_page_toasts, ADW_TYPE_BIN)
+G_DEFINE_TYPE (AdwDemoPageToasts, adw_demo_page_toasts, ADW_TYPE_BIN)
 
 static void
 add_toast (AdwDemoPageToasts *self,
@@ -91,13 +90,6 @@ toast_dismiss_cb (AdwDemoPageToasts *self)
     adw_toast_dismiss (self->undo_toast);
 }
 
-static void
-toast_dismiss_all_cb (AdwDemoPageToasts *self)
-{
-  g_signal_emit (self, signals[SIGNAL_DISMISS_ALL], 0);
-  self->undo_toast = NULL;
-}
-
 static void
 adw_demo_page_toasts_class_init (AdwDemoPageToastsClass *klass)
 {
@@ -112,22 +104,12 @@ adw_demo_page_toasts_class_init (AdwDemoPageToastsClass *klass)
                   G_TYPE_NONE, 1,
                   ADW_TYPE_TOAST);
 
-  signals[SIGNAL_DISMISS_ALL] =
-    g_signal_new ("dismiss-all",
-                  G_TYPE_FROM_CLASS (klass),
-                  G_SIGNAL_RUN_FIRST,
-                  0,
-                  NULL, NULL, NULL,
-                  G_TYPE_NONE, 0);
-
-
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/Adwaita1/Demo/ui/pages/toasts/adw-demo-page-toasts.ui");
 
   gtk_widget_class_install_action (widget_class, "toast.add", NULL, (GtkWidgetActionActivateFunc) toast_add_cb);
   gtk_widget_class_install_action (widget_class, "toast.add-with-button", NULL, (GtkWidgetActionActivateFunc) toast_add_with_button_cb);
   gtk_widget_class_install_action (widget_class, "toast.add-with-long-title", NULL, (GtkWidgetActionActivateFunc) toast_add_with_long_title_cb);
   gtk_widget_class_install_action (widget_class, "toast.dismiss", NULL, (GtkWidgetActionActivateFunc) toast_dismiss_cb);
-  gtk_widget_class_install_action (widget_class, "toast.dismiss-all", NULL, (GtkWidgetActionActivateFunc) toast_dismiss_all_cb);
 }
 
 static void
