@@ -7,8 +7,7 @@
 #include "config.h"
 #include "adw-action-row.h"
 
-#include "adw-marshalers.h"
-#include "adw-widget-utils-private.h"
+#include "adw-macros-private.h"
 
 /**
  * AdwActionRow:
@@ -47,6 +46,8 @@
  *
  * It contains subnodes `label.title` and `label.subtitle` representing
  * respectively the title label and subtitle label.
+ *
+ * Since: 1.0
  */
 
 typedef struct
@@ -63,7 +64,6 @@ typedef struct
 
   int title_lines;
   int subtitle_lines;
-  gboolean subtitle_selectable;
   GtkWidget *activatable_widget;
   GBinding *activatable_binding;
 } AdwActionRowPrivate;
@@ -84,7 +84,6 @@ enum {
   PROP_ACTIVATABLE_WIDGET,
   PROP_TITLE_LINES,
   PROP_SUBTITLE_LINES,
-  PROP_SUBTITLE_SELECTABLE,
   LAST_PROP,
 };
 
@@ -155,9 +154,6 @@ adw_action_row_get_property (GObject    *object,
   case PROP_TITLE_LINES:
     g_value_set_int (value, adw_action_row_get_title_lines (self));
     break;
-  case PROP_SUBTITLE_SELECTABLE:
-    g_value_set_boolean (value, adw_action_row_get_subtitle_selectable (self));
-    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
   }
@@ -187,9 +183,6 @@ adw_action_row_set_property (GObject      *object,
   case PROP_TITLE_LINES:
     adw_action_row_set_title_lines (self, g_value_get_int (value));
     break;
-  case PROP_SUBTITLE_SELECTABLE:
-    adw_action_row_set_subtitle_selectable (self, g_value_get_boolean (value));
-    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
   }
@@ -241,6 +234,8 @@ adw_action_row_class_init (AdwActionRowClass *klass)
    *
    * The subtitle is interpreted as Pango markup unless
    * [property@PreferencesRow:use-markup] is set to `FALSE`.
+   *
+   * Since: 1.0
    */
   props[PROP_SUBTITLE] =
     g_param_spec_string ("subtitle", NULL, NULL,
@@ -252,7 +247,7 @@ adw_action_row_class_init (AdwActionRowClass *klass)
    *
    * The icon name for this row.
    *
-   * Deprecated: 1.3: Use [method@ActionRow.add_prefix] to add an icon.
+   * Since: 1.0
    */
   props[PROP_ICON_NAME] =
     g_param_spec_string ("icon-name", NULL, NULL,
@@ -271,6 +266,8 @@ adw_action_row_class_init (AdwActionRowClass *klass)
    *
    * The target widget will be activated by emitting the
    * [signal@Gtk.Widget::mnemonic-activate] signal on it.
+   *
+   * Since: 1.0
    */
   props[PROP_ACTIVATABLE_WIDGET] =
     g_param_spec_object ("activatable-widget", NULL, NULL,
@@ -283,6 +280,8 @@ adw_action_row_class_init (AdwActionRowClass *klass)
    * The number of lines at the end of which the title label will be ellipsized.
    *
    * If the value is 0, the number of lines won't be limited.
+   *
+   * Since: 1.0
    */
   props[PROP_TITLE_LINES] =
     g_param_spec_int ("title-lines", NULL, NULL,
@@ -297,6 +296,8 @@ adw_action_row_class_init (AdwActionRowClass *klass)
    * ellipsized.
    *
    * If the value is 0, the number of lines won't be limited.
+   *
+   * Since: 1.0
    */
   props[PROP_SUBTITLE_LINES] =
     g_param_spec_int ("subtitle-lines", NULL, NULL,
@@ -304,39 +305,23 @@ adw_action_row_class_init (AdwActionRowClass *klass)
                       0,
                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
-  /**
-   * AdwActionRow:subtitle-selectable: (attributes org.gtk.Property.get=adw_action_row_get_subtitle_selectable org.gtk.Property.set=adw_action_row_set_subtitle_selectable)
-   *
-   * Whether the user can copy the subtitle from the label.
-   *
-   * See also [property@Gtk.Label:selectable].
-   *
-   * Since: 1.3
-   */
-  props[PROP_SUBTITLE_SELECTABLE] =
-    g_param_spec_boolean ("subtitle-selectable", NULL, NULL,
-                          FALSE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
-
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
   /**
    * AdwActionRow::activated:
    *
    * This signal is emitted after the row has been activated.
+   *
+   * Since: 1.0
    */
   signals[SIGNAL_ACTIVATED] =
     g_signal_new ("activated",
                   G_TYPE_FROM_CLASS (klass),
                   G_SIGNAL_RUN_LAST,
                   0,
-                  NULL, NULL,
-                  adw_marshal_VOID__VOID,
+                  NULL, NULL, NULL,
                   G_TYPE_NONE,
                   0);
-  g_signal_set_va_marshaller (signals[SIGNAL_ACTIVATED],
-                              G_TYPE_FROM_CLASS (klass),
-                              adw_marshal_VOID__VOIDv);
 
   gtk_widget_class_set_template_from_resource (widget_class,
                                                "/org/gnome/Adwaita/ui/adw-action-row.ui");
@@ -392,6 +377,8 @@ adw_action_row_buildable_init (GtkBuildableIface *iface)
  * Creates a new `AdwActionRow`.
  *
  * Returns: the newly created `AdwActionRow`
+ *
+ * Since: 1.0
  */
 GtkWidget *
 adw_action_row_new (void)
@@ -405,6 +392,8 @@ adw_action_row_new (void)
  * @widget: a widget
  *
  * Adds a prefix widget to @self.
+ *
+ * Since: 1.0
  */
 void
 adw_action_row_add_prefix (AdwActionRow *self,
@@ -418,7 +407,7 @@ adw_action_row_add_prefix (AdwActionRow *self,
   priv = adw_action_row_get_instance_private (self);
 
   gtk_box_prepend (priv->prefixes, widget);
-  gtk_widget_set_visible (GTK_WIDGET (priv->prefixes), TRUE);
+  gtk_widget_show (GTK_WIDGET (priv->prefixes));
 }
 
 /**
@@ -427,6 +416,8 @@ adw_action_row_add_prefix (AdwActionRow *self,
  * @widget: a widget
  *
  * Adds a suffix widget to @self.
+ *
+ * Since: 1.0
  */
 void
 adw_action_row_add_suffix (AdwActionRow *self,
@@ -440,7 +431,7 @@ adw_action_row_add_suffix (AdwActionRow *self,
   priv = adw_action_row_get_instance_private (self);
 
   gtk_box_append (priv->suffixes, widget);
-  gtk_widget_set_visible (GTK_WIDGET (priv->suffixes), TRUE);
+  gtk_widget_show (GTK_WIDGET (priv->suffixes));
 }
 
 /**
@@ -449,6 +440,8 @@ adw_action_row_add_suffix (AdwActionRow *self,
  * @widget: the child to be removed
  *
  * Removes a child from @self.
+ *
+ * Since: 1.0
  */
 void
 adw_action_row_remove (AdwActionRow *self,
@@ -480,6 +473,8 @@ adw_action_row_remove (AdwActionRow *self,
  * Gets the subtitle for @self.
  *
  * Returns: (nullable): the subtitle for @self
+ *
+ * Since: 1.0
  */
 const char *
 adw_action_row_get_subtitle (AdwActionRow *self)
@@ -502,6 +497,8 @@ adw_action_row_get_subtitle (AdwActionRow *self)
  *
  * The subtitle is interpreted as Pango markup unless
  * [property@PreferencesRow:use-markup] is set to `FALSE`.
+ *
+ * Since: 1.0
  */
 void
 adw_action_row_set_subtitle (AdwActionRow *self,
@@ -529,7 +526,7 @@ adw_action_row_set_subtitle (AdwActionRow *self,
  *
  * Returns: (nullable): the icon name for @self
  *
- * Deprecated: 1.3: Use [method@ActionRow.add_prefix] to add an icon.
+ * Since: 1.0
  */
 const char *
 adw_action_row_get_icon_name (AdwActionRow *self)
@@ -550,7 +547,7 @@ adw_action_row_get_icon_name (AdwActionRow *self)
  *
  * Sets the icon name for @self.
  *
- * Deprecated: 1.3: Use [method@ActionRow.add_prefix] to add an icon.
+ * Since: 1.0
  */
 void
 adw_action_row_set_icon_name (AdwActionRow *self,
@@ -579,6 +576,8 @@ adw_action_row_set_icon_name (AdwActionRow *self,
  * Gets the widget activated when @self is activated.
  *
  * Returns: (nullable) (transfer none): the activatable widget for @self
+ *
+ * Since: 1.0
  */
 GtkWidget *
 adw_action_row_get_activatable_widget (AdwActionRow *self)
@@ -618,6 +617,8 @@ activatable_widget_weak_notify (gpointer  data,
  *
  * The target widget will be activated by emitting the
  * [signal@Gtk.Widget::mnemonic-activate] signal on it.
+ *
+ * Since: 1.0
  */
 void
 adw_action_row_set_activatable_widget (AdwActionRow *self,
@@ -676,6 +677,8 @@ adw_action_row_set_activatable_widget (AdwActionRow *self,
  *
  * Returns: the number of lines at the end of which the title label will be
  *   ellipsized
+ *
+ * Since: 1.0
  */
 int
 adw_action_row_get_title_lines (AdwActionRow *self)
@@ -698,6 +701,8 @@ adw_action_row_get_title_lines (AdwActionRow *self)
  * ellipsized.
  *
  * If the value is 0, the number of lines won't be limited.
+ *
+ * Since: 1.0
  */
 void
 adw_action_row_set_title_lines (AdwActionRow *self,
@@ -730,6 +735,8 @@ adw_action_row_set_title_lines (AdwActionRow *self,
  *
  * Returns: the number of lines at the end of which the subtitle label will be
  *   ellipsized
+ *
+ * Since: 1.0
  */
 int
 adw_action_row_get_subtitle_lines (AdwActionRow *self)
@@ -752,6 +759,8 @@ adw_action_row_get_subtitle_lines (AdwActionRow *self)
  * ellipsized.
  *
  * If the value is 0, the number of lines won't be limited.
+ *
+ * Since: 1.0
  */
 void
 adw_action_row_set_subtitle_lines (AdwActionRow *self,
@@ -775,60 +784,13 @@ adw_action_row_set_subtitle_lines (AdwActionRow *self,
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_SUBTITLE_LINES]);
 }
 
-/**
- * adw_action_row_get_subtitle_selectable: (attributes org.gtk.Method.get_property=subtitle-selectable)
- * @self: a `AdwActionRow`
- *
- * Gets whether the user can copy the subtitle from the label
- *
- * Returns: whether the user can copy the subtitle from the label
- *
- * Since: 1.3
- */
-gboolean
-adw_action_row_get_subtitle_selectable (AdwActionRow *self)
-{
-  AdwActionRowPrivate *priv = adw_action_row_get_instance_private (self);
-
-  g_return_val_if_fail (ADW_IS_ACTION_ROW (self), FALSE);
-
-  return priv->subtitle_selectable;
-}
-
-/**
- * adw_action_row_set_subtitle_selectable: (attributes org.gtk.Method.set_property=subtitle-selectable)
- * @self: a `AdwActionRow`
- * @subtitle_selectable: `TRUE` if the user can copy the subtitle from the label
- *
- * Sets whether the user can copy the subtitle from the label
- *
- * See also [property@Gtk.Label:selectable].
- *
- * Since: 1.3
- */
-void
-adw_action_row_set_subtitle_selectable (AdwActionRow *self,
-                                        gboolean      subtitle_selectable)
-{
-  AdwActionRowPrivate *priv = adw_action_row_get_instance_private (self);
-
-  g_return_if_fail (ADW_IS_ACTION_ROW (self));
-
-  subtitle_selectable = !!subtitle_selectable;
-
-  if (priv->subtitle_selectable == subtitle_selectable)
-    return;
-
-  priv->subtitle_selectable = subtitle_selectable;
-
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_SUBTITLE_SELECTABLE]);
-}
-
 /**
  * adw_action_row_activate:
  * @self: an action row
  *
  * Activates @self.
+ *
+ * Since: 1.0
  */
 void
 adw_action_row_activate (AdwActionRow *self)
