@@ -3,7 +3,7 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * Author: Alice Mikhaylenko <alice.mikhaylenko@puri.sm>
+ * Author: Alexander Mikhaylenko <alexander.mikhaylenko@puri.sm>
  */
 
 #include "config.h"
@@ -26,6 +26,8 @@
  *
  * It is useful for deriving subclasses, since it provides common code needed
  * for handling a single child widget.
+ *
+ * Since: 1.0
  */
 
 typedef struct
@@ -105,12 +107,13 @@ adw_bin_class_init (AdwBinClass *klass)
   object_class->set_property = adw_bin_set_property;
 
   widget_class->compute_expand = adw_widget_compute_expand;
-  widget_class->focus = adw_widget_focus_child;
 
   /**
-   * AdwBin:child:
+   * AdwBin:child: (attributes org.gtk.Property.get=adw_bin_get_child org.gtk.Property.set=adw_bin_set_child)
    *
    * The child widget of the `AdwBin`.
+   *
+   * Since: 1.0
    */
   props[PROP_CHILD] =
     g_param_spec_object ("child", NULL, NULL,
@@ -153,6 +156,8 @@ adw_bin_buildable_init (GtkBuildableIface *iface)
  * Creates a new `AdwBin`.
  *
  * Returns: the new created `AdwBin`
+ *
+ * Since: 1.0
  */
 GtkWidget *
 adw_bin_new (void)
@@ -161,12 +166,14 @@ adw_bin_new (void)
 }
 
 /**
- * adw_bin_get_child:
+ * adw_bin_get_child: (attributes org.gtk.Method.get_property=child)
  * @self: a bin
  *
  * Gets the child widget of @self.
  *
  * Returns: (nullable) (transfer none): the child widget of @self
+ *
+ * Since: 1.0
  */
 GtkWidget *
 adw_bin_get_child (AdwBin *self)
@@ -181,11 +188,13 @@ adw_bin_get_child (AdwBin *self)
 }
 
 /**
- * adw_bin_set_child:
+ * adw_bin_set_child: (attributes org.gtk.Method.set_property=child)
  * @self: a bin
  * @child: (nullable): the child widget
  *
  * Sets the child widget of @self.
+ *
+ * Since: 1.0
  */
 void
 adw_bin_set_child (AdwBin    *self,
@@ -201,9 +210,6 @@ adw_bin_set_child (AdwBin    *self,
   if (priv->child == child)
     return;
 
-  if (child)
-    g_return_if_fail (gtk_widget_get_parent (child) == NULL);
-
   if (priv->child)
     gtk_widget_unparent (priv->child);
 
