@@ -3,7 +3,7 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * Author: Alice Mikhaylenko <alice.mikhaylenko@puri.sm>
+ * Author: Alexander Mikhaylenko <alexander.mikhaylenko@puri.sm>
  */
 
 #include "config.h"
@@ -11,6 +11,7 @@
 #include "adw-tab-bar-private.h"
 
 #include "adw-bin.h"
+#include "adw-macros-private.h"
 #include "adw-tab-box-private.h"
 #include "adw-widget-utils-private.h"
 
@@ -25,7 +26,7 @@
  * </picture>
  *
  * The `AdwTabBar` widget is a tab bar that can be used with conjunction with
- * `AdwTabView`. It is typically used as a top bar within [class@ToolbarView].
+ * `AdwTabView`.
  *
  * `AdwTabBar` can autohide and can optionally contain action widgets on both
  * sides of the tabs.
@@ -38,17 +39,7 @@
  *
  * `AdwTabBar` has a single CSS node with name `tabbar`.
  *
- * ## Style classes
- *
- * By default `AdwTabBar` look like a part of an `AdwHeaderBar` and is intended
- * to be used directly attached to one or used as a [class@ToolbarView] toolbar.
- * The [`.inline`](style-classes.html#inline) style class removes its background,
- * so that it can be used in different contexts instead.
- *
- * <picture>
- *   <source srcset="tab-bar-inline-dark.png" media="(prefers-color-scheme: dark)">
- *   <img src="tab-bar-inline.png" alt="tab-bar-inline">
- * </picture>
+ * Since: 1.0
  */
 
 struct _AdwTabBar
@@ -68,8 +59,6 @@ struct _AdwTabBar
   AdwTabView *view;
   gboolean autohide;
 
-  GdkDragAction extra_drag_preferred_action;
-
   gboolean is_overflowing;
   gboolean resize_frozen;
 };
@@ -89,8 +78,6 @@ enum {
   PROP_EXPAND_TABS,
   PROP_INVERTED,
   PROP_IS_OVERFLOWING,
-  PROP_EXTRA_DRAG_PRELOAD,
-  PROP_EXTRA_DRAG_PREFERRED_ACTION,
   LAST_PROP
 };
 
@@ -98,7 +85,6 @@ static GParamSpec *props[LAST_PROP];
 
 enum {
   SIGNAL_EXTRA_DRAG_DROP,
-  SIGNAL_EXTRA_DRAG_VALUE,
   SIGNAL_LAST_SIGNAL,
 };
 
@@ -254,93 +240,24 @@ stop_kinetic_scrolling_cb (GtkScrolledWindow *scrolled_window)
   gtk_scrolled_window_set_kinetic_scrolling (scrolled_window, TRUE);
 }
 
-static void
-set_extra_drag_preferred_action (AdwTabBar    *self,
-                                 GdkDragAction preferred_action)
-{
-  self->extra_drag_preferred_action = preferred_action;
-
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_EXTRA_DRAG_PREFERRED_ACTION]);
-}
-
 static gboolean
-extra_drag_drop_cb (AdwTabBar    *self,
-                    AdwTabPage   *page,
-                    GValue       *value,
-                    GdkDragAction preferred_action)
+extra_drag_drop_cb (AdwTabBar  *self,
+                    AdwTabPage *page,
+                    GValue     *value)
 {
   gboolean ret = GDK_EVENT_PROPAGATE;
 
-  set_extra_drag_preferred_action (self, preferred_action);
   g_signal_emit (self, signals[SIGNAL_EXTRA_DRAG_DROP], 0, page, value, &ret);
-  set_extra_drag_preferred_action (self, 0);
 
   return ret;
 }
 
-static GdkDragAction
-extra_drag_value_cb (AdwTabBar  *self,
-                     AdwTabPage *page,
-                     GValue     *value)
-{
-  GdkDragAction preferred_action;
-
-  g_signal_emit (self, signals[SIGNAL_EXTRA_DRAG_VALUE], 0, page, value, &preferred_action);
-
-  return preferred_action;
-}
-
-static GdkDragAction
-extra_drag_value_notify (AdwTabBar *self,
-                         GValue    *value)
-{
-  return GDK_ACTION_ALL;
-}
-
 static void
 view_destroy_cb (AdwTabBar *self)
 {
   adw_tab_bar_set_view (self, NULL);
 }
 
-static gboolean
-handle_action_bin_focus (AdwTabBar        *self,
-                         AdwBin           *focused_bin,
-                         GtkDirectionType  dir,
-                         gboolean          dir_towards_tabs)
-{
-  if (gtk_widget_child_focus (GTK_WIDGET (focused_bin), dir))
-    return GDK_EVENT_STOP;
-
-  if (dir == GTK_DIR_UP || dir == GTK_DIR_DOWN)
-    return GDK_EVENT_PROPAGATE;
-
-  if (dir_towards_tabs) {
-    AdwTabPage *selected_page = adw_tab_view_get_selected_page (self->view);
-
-    if (!selected_page) {
-      GtkWidget *other_bin;
-
-      if (focused_bin == self->start_action_bin)
-        other_bin = GTK_WIDGET (self->end_action_bin);
-      else
-        other_bin = GTK_WIDGET (self->start_action_bin);
-
-      if (gtk_widget_child_focus (other_bin, dir))
-        return GDK_EVENT_STOP;
-
-      return gtk_widget_keynav_failed (GTK_WIDGET (self), dir);
-    }
-
-    if (adw_tab_page_get_pinned (selected_page))
-      return gtk_widget_child_focus (GTK_WIDGET (self->pinned_box), dir);
-
-    return gtk_widget_child_focus (GTK_WIDGET (self->box), dir);
-  }
-
-  return gtk_widget_keynav_failed (GTK_WIDGET (self), dir);
-}
-
 static gboolean
 adw_tab_bar_focus (GtkWidget        *widget,
                    GtkDirectionType  direction)
@@ -352,65 +269,23 @@ adw_tab_bar_focus (GtkWidget        *widget,
   if (!adw_tab_bar_get_tabs_revealed (self))
     return GDK_EVENT_PROPAGATE;
 
+  if (!gtk_widget_get_focus_child (widget))
+    return gtk_widget_child_focus (GTK_WIDGET (self->pinned_box), direction) ||
+           gtk_widget_child_focus (GTK_WIDGET (self->box), direction);
+
   is_rtl = gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL;
   start = is_rtl ? GTK_DIR_RIGHT : GTK_DIR_LEFT;
   end = is_rtl ? GTK_DIR_LEFT : GTK_DIR_RIGHT;
 
-  if (!gtk_widget_get_focus_child (widget)) {
-    if (direction == start || direction == GTK_DIR_TAB_BACKWARD || direction == GTK_DIR_UP) {
-      return gtk_widget_child_focus (GTK_WIDGET (self->end_action_bin), direction) ||
-             gtk_widget_child_focus (GTK_WIDGET (self->box), direction) ||
-             gtk_widget_child_focus (GTK_WIDGET (self->pinned_box), direction) ||
-             gtk_widget_child_focus (GTK_WIDGET (self->start_action_bin), direction);
-    } else {
-      return gtk_widget_child_focus (GTK_WIDGET (self->start_action_bin), direction) ||
-             gtk_widget_child_focus (GTK_WIDGET (self->pinned_box), direction) ||
-             gtk_widget_child_focus (GTK_WIDGET (self->box), direction) ||
-             gtk_widget_child_focus (GTK_WIDGET (self->end_action_bin), direction);
-    }
-  }
-
-  if (gtk_widget_get_focus_child (GTK_WIDGET (self->start_action_bin))) {
-    return handle_action_bin_focus (self,
-                                    self->start_action_bin,
-                                    direction,
-                                    direction == end || direction == GTK_DIR_TAB_FORWARD);
-  }
-
-  if (gtk_widget_get_focus_child (GTK_WIDGET (self->end_action_bin))) {
-    return handle_action_bin_focus (self,
-                                    self->end_action_bin,
-                                    direction,
-                                    direction == start || direction == GTK_DIR_TAB_BACKWARD);
-  }
-
-  /* If the focus is not in either action_bin, then it must be in the tabs */
-
   if (direction == start) {
-    if (adw_tab_view_select_previous_page (self->view) ||
-        gtk_widget_child_focus (GTK_WIDGET (self->start_action_bin), direction))
+    if (adw_tab_view_select_previous_page (self->view))
       return GDK_EVENT_STOP;
 
     return gtk_widget_keynav_failed (widget, direction);
   }
 
   if (direction == end) {
-    if (adw_tab_view_select_next_page (self->view) ||
-        gtk_widget_child_focus (GTK_WIDGET (self->end_action_bin), direction))
-      return GDK_EVENT_STOP;
-
-    return gtk_widget_keynav_failed (widget, direction);
-  }
-
-  if (direction == GTK_DIR_TAB_BACKWARD) {
-    if (gtk_widget_child_focus (GTK_WIDGET (self->start_action_bin), direction))
-      return GDK_EVENT_STOP;
-
-    return gtk_widget_keynav_failed (widget, direction);
-  }
-
-  if (direction == GTK_DIR_TAB_FORWARD) {
-    if (gtk_widget_child_focus (GTK_WIDGET (self->end_action_bin), direction))
+    if (adw_tab_view_select_next_page (self->view))
       return GDK_EVENT_STOP;
 
     return gtk_widget_keynav_failed (widget, direction);
@@ -426,7 +301,7 @@ adw_tab_bar_dispose (GObject *object)
 
   adw_tab_bar_set_view (self, NULL);
 
-  gtk_widget_dispose_template (GTK_WIDGET (self), ADW_TYPE_TAB_BAR);
+  gtk_widget_unparent (GTK_WIDGET (self->revealer));
 
   G_OBJECT_CLASS (adw_tab_bar_parent_class)->dispose (object);
 }
@@ -472,14 +347,6 @@ adw_tab_bar_get_property (GObject    *object,
     g_value_set_boolean (value, adw_tab_bar_get_is_overflowing (self));
     break;
 
-  case PROP_EXTRA_DRAG_PREFERRED_ACTION:
-    g_value_set_flags (value, adw_tab_bar_get_extra_drag_preferred_action (self));
-    break;
-
-  case PROP_EXTRA_DRAG_PRELOAD:
-    g_value_set_boolean (value, adw_tab_bar_get_extra_drag_preload (self));
-    break;
-
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
   }
@@ -518,10 +385,6 @@ adw_tab_bar_set_property (GObject      *object,
     adw_tab_bar_set_inverted (self, g_value_get_boolean (value));
     break;
 
-  case PROP_EXTRA_DRAG_PRELOAD:
-    adw_tab_bar_set_extra_drag_preload (self, g_value_get_boolean (value));
-    break;
-
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
   }
@@ -541,9 +404,11 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
   widget_class->compute_expand = adw_widget_compute_expand;
 
   /**
-   * AdwTabBar:view:
+   * AdwTabBar:view: (attributes org.gtk.Property.get=adw_tab_bar_get_view org.gtk.Property.set=adw_tab_bar_set_view)
    *
    * The tab view the tab bar controls.
+   *
+   * Since: 1.0
    */
   props[PROP_VIEW] =
     g_param_spec_object ("view", NULL, NULL,
@@ -551,9 +416,11 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwTabBar:start-action-widget:
+   * AdwTabBar:start-action-widget: (attributes org.gtk.Property.get=adw_tab_bar_get_start_action_widget org.gtk.Property.set=adw_tab_bar_set_start_action_widget)
    *
    * The widget shown before the tabs.
+   *
+   * Since: 1.0
    */
   props[PROP_START_ACTION_WIDGET] =
     g_param_spec_object ("start-action-widget", NULL, NULL,
@@ -561,9 +428,11 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwTabBar:end-action-widget:
+   * AdwTabBar:end-action-widget: (attributes org.gtk.Property.get=adw_tab_bar_get_end_action_widget org.gtk.Property.set=adw_tab_bar_set_end_action_widget)
    *
    * The widget shown after the tabs.
+   *
+   * Since: 1.0
    */
   props[PROP_END_ACTION_WIDGET] =
     g_param_spec_object ("end-action-widget", NULL, NULL,
@@ -571,7 +440,7 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwTabBar:autohide:
+   * AdwTabBar:autohide: (attributes org.gtk.Property.get=adw_tab_bar_get_autohide org.gtk.Property.set=adw_tab_bar_set_autohide)
    *
    * Whether the tabs automatically hide.
    *
@@ -579,6 +448,8 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
    * or 1 tab, no pinned tabs, and no tab is being transferred.
    *
    * See [property@TabBar:tabs-revealed].
+   *
+   * Since: 1.0
    */
   props[PROP_AUTOHIDE] =
     g_param_spec_boolean ("autohide", NULL, NULL,
@@ -586,11 +457,13 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwTabBar:tabs-revealed:
+   * AdwTabBar:tabs-revealed: (attributes org.gtk.Property.get=adw_tab_bar_get_tabs_revealed)
    *
    * Whether the tabs are currently revealed.
    *
    * See [property@TabBar:autohide].
+   *
+   * Since: 1.0
    */
   props[PROP_TABS_REVEALED] =
     g_param_spec_boolean ("tabs-revealed", NULL, NULL,
@@ -598,12 +471,14 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
                           G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   /**
-   * AdwTabBar:expand-tabs:
+   * AdwTabBar:expand-tabs: (attributes org.gtk.Property.get=adw_tab_bar_get_expand_tabs org.gtk.Property.set=adw_tab_bar_set_expand_tabs)
    *
    * Whether tabs expand to full width.
    *
    * If set to `TRUE`, the tabs will always vary width filling the whole width
    * when possible, otherwise tabs will always have the minimum possible size.
+   *
+   * Since: 1.0
    */
   props[PROP_EXPAND_TABS] =
     g_param_spec_boolean ("expand-tabs", NULL, NULL,
@@ -611,12 +486,14 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwTabBar:inverted:
+   * AdwTabBar:inverted: (attributes org.gtk.Property.get=adw_tab_bar_get_inverted org.gtk.Property.set=adw_tab_bar_set_inverted)
    *
    * Whether tabs use inverted layout.
    *
    * If set to `TRUE`, non-pinned tabs will have the close button at the
    * beginning and the indicator at the end rather than the opposite.
+   *
+   * Since: 1.0
    */
   props[PROP_INVERTED] =
     g_param_spec_boolean ("inverted", NULL, NULL,
@@ -624,48 +501,19 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwTabBar:is-overflowing:
+   * AdwTabBar:is-overflowing: (attributes org.gtk.Property.get=adw_tab_bar_get_is_overflowing)
    *
    * Whether the tab bar is overflowing.
    *
    * If `TRUE`, all tabs cannot be displayed at once and require scrolling.
+   *
+   * Since: 1.0
    */
   props[PROP_IS_OVERFLOWING] =
     g_param_spec_boolean ("is-overflowing", NULL, NULL,
                           FALSE,
                           G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
-  /**
-   * AdwTabBar:extra-drag-preferred-action:
-   *
-   * The unique action on the `current-drop` of the
-   * [signal@TabBar::extra-drag-drop].
-   *
-   * This property should only be used during a [signal@TabBar::extra-drag-drop]
-   * and is always a subset of what was originally passed to
-   * [method@TabBar.setup_extra_drop_target].
-   *
-   * Since: 1.4
-   */
-  props[PROP_EXTRA_DRAG_PREFERRED_ACTION] =
-    g_param_spec_flags ("extra-drag-preferred-action", NULL, NULL,
-                       GDK_TYPE_DRAG_ACTION, 0,
-                       G_PARAM_READABLE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
-
-  /**
-   * AdwTabBar:extra-drag-preload:
-   *
-   * Whether the drop data should be preloaded on hover.
-   *
-   * See [property@Gtk.DropTarget:preload].
-   *
-   * Since: 1.3
-   */
-  props[PROP_EXTRA_DRAG_PRELOAD] =
-    g_param_spec_boolean ("extra-drag-preload", NULL, NULL,
-                          FALSE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
-
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
   /**
@@ -682,51 +530,20 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
    * See [signal@Gtk.DropTarget::drop].
    *
    * Returns: whether the drop was accepted for @page
+   *
+   * Since: 1.0
    */
   signals[SIGNAL_EXTRA_DRAG_DROP] =
     g_signal_new ("extra-drag-drop",
                   G_TYPE_FROM_CLASS (klass),
                   G_SIGNAL_RUN_LAST,
                   0,
-                  g_signal_accumulator_first_wins,
-                  NULL, NULL,
+                  g_signal_accumulator_first_wins, NULL, NULL,
                   G_TYPE_BOOLEAN,
                   2,
                   ADW_TYPE_TAB_PAGE,
                   G_TYPE_VALUE);
 
-  /**
-   * AdwTabBar::extra-drag-value:
-   * @self: a tab bar
-   * @page: the page matching the tab the content was dropped onto
-   * @value: the `GValue` being dropped
-   *
-   * This signal is emitted when the dropped content is preloaded.
-   *
-   * In order for data to be preloaded, [property@TabBar:extra-drag-preload]
-   * must be set to `TRUE`.
-   *
-   * The content must be of one of the types set up via
-   * [method@TabBar.setup_extra_drop_target].
-   *
-   * See [property@Gtk.DropTarget:value].
-   *
-   * Returns: the preferred action for the drop on @page
-   *
-   * Since: 1.3
-   */
-  signals[SIGNAL_EXTRA_DRAG_VALUE] =
-    g_signal_new ("extra-drag-value",
-                  G_TYPE_FROM_CLASS (klass),
-                  G_SIGNAL_RUN_LAST,
-                  0,
-                  g_signal_accumulator_first_wins,
-                  NULL, NULL,
-                  GDK_TYPE_DRAG_ACTION,
-                  2,
-                  ADW_TYPE_TAB_PAGE,
-                  G_TYPE_VALUE);
-
   gtk_widget_class_set_template_from_resource (widget_class,
                                                "/org/gnome/Adwaita/ui/adw-tab-bar.ui");
   gtk_widget_class_bind_template_child (widget_class, AdwTabBar, revealer);
@@ -739,14 +556,10 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, notify_resize_frozen_cb);
   gtk_widget_class_bind_template_callback (widget_class, stop_kinetic_scrolling_cb);
   gtk_widget_class_bind_template_callback (widget_class, extra_drag_drop_cb);
-  gtk_widget_class_bind_template_callback (widget_class, extra_drag_value_cb);
 
   gtk_widget_class_set_layout_manager_type (widget_class, GTK_TYPE_BIN_LAYOUT);
   gtk_widget_class_set_css_name (widget_class, "tabbar");
 
-  g_signal_override_class_handler ("extra-drag-value", G_TYPE_FROM_CLASS (klass),
-                                   G_CALLBACK (extra_drag_value_notify));
-
   g_type_ensure (ADW_TYPE_TAB_BOX);
 }
 
@@ -830,6 +643,8 @@ adw_tab_bar_tabs_have_visible_focus (AdwTabBar *self)
  * Creates a new `AdwTabBar`.
  *
  * Returns: the newly created `AdwTabBar`
+ *
+ * Since: 1.0
  */
 AdwTabBar *
 adw_tab_bar_new (void)
@@ -838,12 +653,14 @@ adw_tab_bar_new (void)
 }
 
 /**
- * adw_tab_bar_get_view:
+ * adw_tab_bar_get_view: (attributes org.gtk.Method.get_property=view)
  * @self: a tab bar
  *
  * Gets the tab view @self controls.
  *
  * Returns: (transfer none) (nullable): the view @self controls
+ *
+ * Since: 1.0
  */
 AdwTabView *
 adw_tab_bar_get_view (AdwTabBar *self)
@@ -854,11 +671,13 @@ adw_tab_bar_get_view (AdwTabBar *self)
 }
 
 /**
- * adw_tab_bar_set_view:
+ * adw_tab_bar_set_view: (attributes org.gtk.Method.set_property=view)
  * @self: a tab bar
  * @view: (nullable): a tab view
  *
  * Sets the tab view @self controls.
+ *
+ * Since: 1.0
  */
 void
 adw_tab_bar_set_view (AdwTabBar  *self,
@@ -930,12 +749,14 @@ adw_tab_bar_set_view (AdwTabBar  *self,
 }
 
 /**
- * adw_tab_bar_get_start_action_widget:
+ * adw_tab_bar_get_start_action_widget: (attributes org.gtk.Method.get_property=start-action-widget)
  * @self: a tab bar
  *
  * Gets the widget shown before the tabs.
  *
  * Returns: (transfer none) (nullable): the widget shown before the tabs
+ *
+ * Since: 1.0
  */
 GtkWidget *
 adw_tab_bar_get_start_action_widget (AdwTabBar *self)
@@ -946,11 +767,13 @@ adw_tab_bar_get_start_action_widget (AdwTabBar *self)
 }
 
 /**
- * adw_tab_bar_set_start_action_widget:
+ * adw_tab_bar_set_start_action_widget: (attributes org.gtk.Method.set_property=start-action-widget)
  * @self: a tab bar
  * @widget: (transfer none) (nullable): the widget to show before the tabs
  *
  * Sets the widget to show before the tabs.
+ *
+ * Since: 1.0
  */
 void
 adw_tab_bar_set_start_action_widget (AdwTabBar *self,
@@ -973,12 +796,14 @@ adw_tab_bar_set_start_action_widget (AdwTabBar *self,
 }
 
 /**
- * adw_tab_bar_get_end_action_widget:
+ * adw_tab_bar_get_end_action_widget: (attributes org.gtk.Method.get_property=end-action-widget)
  * @self: a tab bar
  *
  * Gets the widget shown after the tabs.
  *
  * Returns: (transfer none) (nullable): the widget shown after the tabs
+ *
+ * Since: 1.0
  */
 GtkWidget *
 adw_tab_bar_get_end_action_widget (AdwTabBar *self)
@@ -989,11 +814,13 @@ adw_tab_bar_get_end_action_widget (AdwTabBar *self)
 }
 
 /**
- * adw_tab_bar_set_end_action_widget:
+ * adw_tab_bar_set_end_action_widget: (attributes org.gtk.Method.set_property=end-action-widget)
  * @self: a tab bar
  * @widget: (transfer none) (nullable): the widget to show after the tabs
  *
  * Sets the widget to show after the tabs.
+ *
+ * Since: 1.0
  */
 void
 adw_tab_bar_set_end_action_widget (AdwTabBar *self,
@@ -1016,12 +843,14 @@ adw_tab_bar_set_end_action_widget (AdwTabBar *self,
 }
 
 /**
- * adw_tab_bar_get_autohide:
+ * adw_tab_bar_get_autohide: (attributes org.gtk.Method.get_property=autohide)
  * @self: a tab bar
  *
  * Gets whether the tabs automatically hide.
  *
  * Returns: whether the tabs automatically hide
+ *
+ * Since: 1.0
  */
 gboolean
 adw_tab_bar_get_autohide (AdwTabBar *self)
@@ -1032,7 +861,7 @@ adw_tab_bar_get_autohide (AdwTabBar *self)
 }
 
 /**
- * adw_tab_bar_set_autohide:
+ * adw_tab_bar_set_autohide: (attributes org.gtk.Method.set_property=autohide)
  * @self: a tab bar
  * @autohide: whether the tabs automatically hide
  *
@@ -1042,6 +871,8 @@ adw_tab_bar_get_autohide (AdwTabBar *self)
  * or 1 tab, no pinned tabs, and no tab is being transferred.
  *
  * See [property@TabBar:tabs-revealed].
+ *
+ * Since: 1.0
  */
 void
 adw_tab_bar_set_autohide (AdwTabBar *self,
@@ -1062,7 +893,7 @@ adw_tab_bar_set_autohide (AdwTabBar *self,
 }
 
 /**
- * adw_tab_bar_get_tabs_revealed:
+ * adw_tab_bar_get_tabs_revealed: (attributes org.gtk.Method.get_property=tabs-revealed)
  * @self: a tab bar
  *
  * Gets whether the tabs are currently revealed.
@@ -1070,6 +901,8 @@ adw_tab_bar_set_autohide (AdwTabBar *self,
  * See [property@TabBar:autohide].
  *
  * Returns: whether the tabs are currently revealed
+ *
+ * Since: 1.0
  */
 gboolean
 adw_tab_bar_get_tabs_revealed (AdwTabBar *self)
@@ -1080,12 +913,14 @@ adw_tab_bar_get_tabs_revealed (AdwTabBar *self)
 }
 
 /**
- * adw_tab_bar_get_expand_tabs:
+ * adw_tab_bar_get_expand_tabs: (attributes org.gtk.Method.get_property=expand-tabs)
  * @self: a tab bar
  *
  * Gets whether tabs expand to full width.
  *
  * Returns: whether tabs expand to full width.
+ *
+ * Since: 1.0
  */
 gboolean
 adw_tab_bar_get_expand_tabs (AdwTabBar *self)
@@ -1096,7 +931,7 @@ adw_tab_bar_get_expand_tabs (AdwTabBar *self)
 }
 
 /**
- * adw_tab_bar_set_expand_tabs:
+ * adw_tab_bar_set_expand_tabs: (attributes org.gtk.Method.set_property=expand-tabs)
  * @self: a tab bar
  * @expand_tabs: whether to expand tabs
  *
@@ -1104,6 +939,8 @@ adw_tab_bar_get_expand_tabs (AdwTabBar *self)
  *
  * If set to `TRUE`, the tabs will always vary width filling the whole width
  * when possible, otherwise tabs will always have the minimum possible size.
+ *
+ * Since: 1.0
  */
 void
 adw_tab_bar_set_expand_tabs (AdwTabBar *self,
@@ -1122,12 +959,14 @@ adw_tab_bar_set_expand_tabs (AdwTabBar *self,
 }
 
 /**
- * adw_tab_bar_get_inverted:
+ * adw_tab_bar_get_inverted: (attributes org.gtk.Method.get_property=inverted)
  * @self: a tab bar
  *
  * Gets whether tabs use inverted layout.
  *
  * Returns: whether tabs use inverted layout
+ *
+ * Since: 1.0
  */
 gboolean
 adw_tab_bar_get_inverted (AdwTabBar *self)
@@ -1138,7 +977,7 @@ adw_tab_bar_get_inverted (AdwTabBar *self)
 }
 
 /**
- * adw_tab_bar_set_inverted:
+ * adw_tab_bar_set_inverted: (attributes org.gtk.Method.set_property=inverted)
  * @self: a tab bar
  * @inverted: whether tabs use inverted layout
  *
@@ -1146,6 +985,8 @@ adw_tab_bar_get_inverted (AdwTabBar *self)
  *
  * If set to `TRUE`, non-pinned tabs will have the close button at the beginning
  * and the indicator at the end rather than the opposite.
+ *
+ * Since: 1.0
  */
 void
 adw_tab_bar_set_inverted (AdwTabBar *self,
@@ -1182,6 +1023,8 @@ adw_tab_bar_set_inverted (AdwTabBar *self,
  * it will be automatically selected.
  *
  * The [signal@TabBar::extra-drag-drop] signal can be used to handle the drop.
+ *
+ * Since: 1.0
  */
 void
 adw_tab_bar_setup_extra_drop_target (AdwTabBar     *self,
@@ -1197,69 +1040,7 @@ adw_tab_bar_setup_extra_drop_target (AdwTabBar     *self,
 }
 
 /**
- * adw_tab_bar_get_extra_drag_preferred_action:
- * @self: a tab bar
- *
- * Gets the current action during a drop on the extra_drop_target.
- *
- * Returns: the drag action of the current drop.
- *
- * Since: 1.4
- */
-GdkDragAction
-adw_tab_bar_get_extra_drag_preferred_action (AdwTabBar *self)
-{
-  g_return_val_if_fail (ADW_IS_TAB_BAR (self), 0);
-
-  return self->extra_drag_preferred_action;
-}
-
-/**
- * adw_tab_bar_get_extra_drag_preload:
- * @self: a tab bar
- *
- * Gets whether drop data should be preloaded on hover.
- *
- * Returns: whether drop data should be preloaded on hover
- *
- * Since: 1.3
- */
-gboolean
-adw_tab_bar_get_extra_drag_preload (AdwTabBar *self)
-{
-  g_return_val_if_fail (ADW_IS_TAB_BAR (self), FALSE);
-
-  return adw_tab_box_get_extra_drag_preload (self->box);
-}
-
-/**
- * adw_tab_bar_set_extra_drag_preload:
- * @self: a tab bar
- * @preload: whether to preload drop data
- *
- * Sets whether drop data should be preloaded on hover.
- *
- * See [property@Gtk.DropTarget:preload].
- *
- * Since: 1.3
- */
-void
-adw_tab_bar_set_extra_drag_preload (AdwTabBar *self,
-                                    gboolean   preload)
-{
-  g_return_if_fail (ADW_IS_TAB_BAR (self));
-
-  if (adw_tab_bar_get_extra_drag_preload (self) == preload)
-    return;
-
-  adw_tab_box_set_extra_drag_preload (self->box, preload);
-  adw_tab_box_set_extra_drag_preload (self->pinned_box, preload);
-
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_EXTRA_DRAG_PRELOAD]);
-}
-
-/**
- * adw_tab_bar_get_is_overflowing:
+ * adw_tab_bar_get_is_overflowing: (attributes org.gtk.Method.get_property=is-overflowing)
  * @self: a tab bar
  *
  * Gets whether @self is overflowing.
@@ -1267,6 +1048,8 @@ adw_tab_bar_set_extra_drag_preload (AdwTabBar *self,
  * If `TRUE`, all tabs cannot be displayed at once and require scrolling.
  *
  * Returns: whether @self is overflowing
+ *
+ * Since: 1.0
  */
 gboolean
 adw_tab_bar_get_is_overflowing (AdwTabBar *self)
