@@ -6,10 +6,12 @@
 
 #include <adwaita.h>
 
+int notified;
+
 static void
-increment (int *data)
+notify_cb (GtkWidget *widget, gpointer data)
 {
-  (*data)++;
+  notified++;
 }
 
 static void
@@ -17,11 +19,11 @@ test_adw_toast_overlay_child (void)
 {
   AdwToastOverlay *toast_overlay = g_object_ref_sink (ADW_TOAST_OVERLAY (adw_toast_overlay_new ()));
   GtkWidget *widget = NULL;
-  int notified = 0;
 
   g_assert_nonnull (toast_overlay);
 
-  g_signal_connect_swapped (toast_overlay, "notify::child", G_CALLBACK (increment), &notified);
+  notified = 0;
+  g_signal_connect (toast_overlay, "notify::child", G_CALLBACK (notify_cb), NULL);
 
   g_object_get (toast_overlay, "child", &widget, NULL);
   g_assert_null (widget);
@@ -58,23 +60,6 @@ test_adw_toast_overlay_add_toast (void)
   g_assert_finalize_object (toast);
 }
 
-static void
-test_adw_toast_overlay_dismiss_all (void)
-{
-  AdwToastOverlay *toast_overlay = g_object_ref_sink (ADW_TOAST_OVERLAY (adw_toast_overlay_new ()));
-  AdwToast *toast = adw_toast_new ("Test Notification");
-
-  g_assert_nonnull (toast_overlay);
-  g_assert_nonnull (toast);
-
-  adw_toast_overlay_add_toast (toast_overlay, g_object_ref (toast));
-
-  adw_toast_overlay_dismiss_all (toast_overlay);
-
-  g_assert_finalize_object (toast_overlay);
-  g_assert_finalize_object (toast);
-}
-
 int
 main (int   argc,
       char *argv[])
@@ -84,7 +69,6 @@ main (int   argc,
 
   g_test_add_func ("/Adwaita/ToastOverlay/child", test_adw_toast_overlay_child);
   g_test_add_func ("/Adwaita/ToastOverlay/add_toast", test_adw_toast_overlay_add_toast);
-  g_test_add_func ("/Adwaita/ToastOverlay/dismiss_all", test_adw_toast_overlay_dismiss_all);
 
   return g_test_run ();
 }
